@@ -7,11 +7,20 @@ has 'table_name' => "tools_objects";
 
 
 
-sub load_tools_version_fkey($self, $tools_projects_pkey) {
+sub load_tools_objects_fkey($self, $tools_projects_pkey) {
 
     return $self->load_fkey(
         $self->table_name, $self->fields(), "tools_version_fkey", $tools_projects_pkey
     );
 }
 
+sub insert_tools_objects($self, $data) {
+    my $result = $self->insert($self->table_name, $data, $self->primary_key_name);
+    return $result;
+}
+
+
+sub update_tools_objects($self, $data) {
+    return $self->update($self->table_name, $data, { $self->primary_key_name() => $data->{$self->primary_key_name()}});
+}
 1;
\ No newline at end of file
